@@ -637,71 +637,6 @@ where
     }
 }
 
-impl<T> From<bool> for FlexStr<T>
-where
-    T: Deref<Target = str>,
-{
-    /// ```
-    /// use flexstr::FlexStr;
-    ///
-    /// let s: FlexStr = false.into();
-    /// assert!(s.is_static());
-    /// assert_eq!(s, "false");
-    /// ```
-    #[inline]
-    fn from(b: bool) -> Self {
-        if b { "true" } else { "false" }.into()
-    }
-}
-
-macro_rules! impl_int_from {
-    ($($type:ty),+) => {
-        $(impl<T> From<$type> for FlexStr<T>
-        where
-            T: for<'a> From<&'a str> + From<String>,
-        {
-            /// ```
-            /// use flexstr::FlexStr;
-            ///
-            #[doc = concat!("let s: FlexStr = 123", stringify!($type), ".into();")]
-            /// assert!(s.is_inlined());
-            /// assert_eq!(s, "123");
-            /// ```
-            #[inline]
-            fn from(i: $type) -> Self {
-                let mut buffer = itoa::Buffer::new();
-                buffer.format(i).to_flex()
-            }
-        })+
-    };
-}
-
-impl_int_from!(i8, u8, i16, u16, i32, u32, i64, u64, i128, u128, isize, usize);
-
-macro_rules! impl_float_from {
-    ($($type:ty),+) => {
-        $(impl<T> From<$type> for FlexStr<T>
-        where
-            T: for<'a> From<&'a str> + From<String>,
-        {
-            /// ```
-            /// use flexstr::FlexStr;
-            ///
-            #[doc = concat!("let s: FlexStr = 123.456", stringify!($type), ".into();")]
-            /// assert!(s.is_inlined());
-            /// assert_eq!(s, "123.456");
-            /// ```
-            #[inline]
-            fn from(f: $type) -> Self {
-                let mut buffer = ryu::Buffer::new();
-                buffer.format(f).to_flex()
-            }
-        })+
-    };
-}
-
-impl_float_from!(f32, f64);
-
 // *** FromIterator ***
 
 fn from_iter_str<I, T, U>(iter: I) -> FlexStr<T>
